# Example R code for solving a Bayesian network
# Consider the Bayesian network with three species:
#    A -> C <-/- B
# where the presence of C is positively affected by A but negatively affected by B
# At a particular location, assume the species have prior probabilities of presence
#    A: 0.7; B: 0.2; and C: 0.4

# Load the required R package for solving Bayesian networks
require(gRain)

# Define the state table (conditional probability table) for A
A <- cptable(~A, values=c(0.7,0.3), levels=c('present', 'absent'))

# Define the state table (conditional probability table) for B
B <- cptable(~B, values=c(0.2,0.8), levels=c('present', 'absent'))

# Define the state table (conditional probability table) for C
# The order is (A=present,B=present) (absent,present) (present,absent) (absent,absent)
C <- cptable(~C|A+B, values=c(0.4,0.6, 0,1, 0.8,0.2, 0.4,0.6), levels=c('present', 'absent'))

# Compile state tables (conditional probability tables)
plist <- compileCPT(list(A, B, C))

# Build the Bayesian network
BN <- grain(plist)

# Solve the Bayesian network
posteriors <- querygrain(BN)

# Display results
print(posteriors)
# The posteriors should be 0.7, 0.2 and 0.6 for species A, B and C, respectively
# (as explained in Box 1 in the main text).
